@@ -1,22 +1,20 @@
 import { ICell, IJupyter } from './types';
 
 const Jupyter: IJupyter = (window as any)['Jupyter'];
-const workRegx = /work\/lessons-(\d+)-(\w+)\.ipynb/;
+export const workRegx = /work\/lessons-(\d+)-(\w+)\.ipynb/;
 
 export const registerBbyButtons = () => {
-  if (workRegx.test(Jupyter.notebook.notebook_path)) {
-    Jupyter.toolbar.add_buttons_group([
-      Jupyter.keyboard_manager.actions.register(
-        {
-          help: '同步课程',
-          icon: 'fa-retweet',
-          handler: syncLesson,
-        },
-        'sync-lesson',
-        'ipybbycell'
-      ),
-    ]);
-  }
+  Jupyter.toolbar.add_buttons_group([
+    Jupyter.keyboard_manager.actions.register(
+      {
+        help: '同步课程',
+        icon: 'fa-retweet',
+        handler: syncLesson,
+      },
+      'sync-lesson',
+      'ipybbycell'
+    ),
+  ]);
   Jupyter.toolbar.add_buttons_group([
     Jupyter.keyboard_manager.actions.register(
       {
